@@ -1,7 +1,10 @@
-from typing import IO
 from os.path import join
 
 from cfinterface.data.blockdata import BlockData
+from cfinterface.adapters.writing.repository import (
+    Repository,
+    factory,
+)
 
 
 class BlockWriting:
@@ -9,19 +12,19 @@ class BlockWriting:
     Class for writing custom files based on a BlockData structure.
     """
 
-    def __init__(self, data: BlockData) -> None:
+    def __init__(self, data: BlockData, storage: str = "") -> None:
         self.__data = data
+        self.__storage = storage
+        self.__repository: Repository = None  # type: ignore
 
-    def __write_file(self, file: IO):
+    def __write_file(self):
         """
         Writes all the blocks from the given BlockData structure
         to the specified file.
 
-        :param file: The filepointer
-        :type file: IO
         """
         for b in self.__data:
-            b.write(file)
+            b.write(self.__repository.file)
 
     def write(self, filename: str, directory: str, encoding: str):
         """
@@ -36,8 +39,9 @@ class BlockWriting:
         :type encoding: str
         """
         filepath = join(directory, filename)
-        with open(filepath, "w", encoding=encoding) as fp:
-            return self.__write_file(fp)
+        self.__repository = factory(self.__storage)(filepath, encoding)
+        with self.__repository:
+            return self.__write_file()
 
     @property
     def data(self) -> BlockData:
