@@ -11,6 +11,10 @@ class DummyRegister(Register):
     IDENTIFIER_DIGITS = 4
     LINE = Line([LiteralField(13, 4)])
 
+    @property
+    def custom_property(self) -> str:
+        return "Custom!"
+
 
 class DummyDelimitedRegister(Register):
     IDENTIFIER = "reg"
@@ -18,6 +22,10 @@ class DummyDelimitedRegister(Register):
     LINE = Line([LiteralField(13, 4)], delimiter=";")
 
 
+class DummyBinaryRegister(Register):
+    LINE = Line([LiteralField(13)], storage="BINARY")
+
+
 def test_single_register_properties():
     r1 = Register()
     assert r1.is_first
@@ -52,6 +60,14 @@ def test_dummy_register_equal():
     assert b1 == b2
 
 
+def test_dummy_register_custom_properties():
+    assert DummyRegister().custom_properties == ["custom_property"]
+
+
+def test_dummy_delimitedregister_custom_properties():
+    assert DummyDelimitedRegister().custom_properties == []
+
+
 def test_dummy_register_read():
     data = "Hello, world!"
     filedata = DummyRegister.IDENTIFIER + " " + data + "\n"
@@ -98,3 +114,27 @@ def test_dummy_delimiterregister_write():
             b.data = [data]
             b.write_register(fp)
     m().write.assert_called_once_with(write_data)
+
+
+def test_dummy_binaryregister_read():
+    data = "Hello, world!"
+    filedata = data.encode("utf-8")
+    m: MagicMock = mock_open(read_data=filedata)
+    with patch("builtins.open", m):
+        with open("", "rb") as fp:
+            b = DummyBinaryRegister()
+            b.read_register(fp, storage="BINARY")
+            assert b.data[0] == data
+
+
+def test_dummy_binaryregister_write():
+    data = "Hello, world!"
+    write_data = data.encode("utf-8")
+    filedata = b""
+    m = mock_open(read_data=filedata)
+    with patch("builtins.open", m):
+        with open("", "wb") as fp:
+            b = DummyBinaryRegister()
+            b.data = [data]
+            b.write_register(fp, storage="BINARY")
+    m().write.assert_called_once_with(write_data)
