@@ -23,7 +23,7 @@ def test_blockwriting_withdata():
     bw = RegisterWriting(bd)
     m: MagicMock = mock_open(read_data=filedata)
     with patch("builtins.open", m):
-        bw.write("", "")
+        bw.write("", "", "utf-8")
     m().write.assert_called_once_with(
         DummyRegister.IDENTIFIER + " " + filedata + "\n"
     )
